==> spip_3.2.11.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'أهلاً وسهلاً @nom@!',
	'c_accueil_configurer_site' => 'إعداد موقعك',
	'c_accueil_configurer_site_texte' => 'أول ما يجب القيام به هو إعطاء اسم لموقعك.
		اسمه الآن «@nom@». سيتم عرض اسم الموقع في أعلى هذه الصفحة.
		بالنقر عليه، يمكن تغيير اسمه واعطاءه رمز وشعار.
',
	'c_accueil_publication' => 'أنشر!',
	'c_accueil_publication_texte' => 'لنشر صفحة، يجب إنشاء مقال.
		لذلك من الضروري انشاء قسم واحد على الأقل. ويتم ذلك من قائمة «تحرير» بانقر على «الأقسام».',
	'c_accueil_texte' => 'دخلت الآن في المجال الخاص في SPIP.',
	'c_accueil_texte_revenir' => 'تعرض هذه الصفحة أحدث نشاطات التحرير في موقعك.
يمكنك العودة الى هذه الصفحة في اي وقت بالنقر على رمز المنزل،
في القسم الأعلى من الشاشة، تحت اسمك.',
	'c_article_redaction' => 'المقال قيد التحرير',
	'c_article_redaction_redacteur' => 'المقال قيد التحرير',
	'c_article_redaction_redacteur_texte' => 'لعرض مقالك على مدراء الموقع وعلى المحررين الآخرين،
		قم بتغيير وضعيته من «قيد التحرير» الى «معروض للتقييم» في الإطار الجانبي.',
	'c_article_redaction_texte' => 'لنشر هذا المقال في الموقع العمومي، يجب تغيير وضعيته.
		قم بتغيير الوضعية من «قيد التحرير» الى «منشور»، في الإطار الجانبي.',
	'c_articles_creer' => 'كيف يتم إنشاء مقال؟',
	'c_articles_creer_texte' => 'لا يمكنك إنشاء مقال من هذه الصفحة
		الا اذا كان يوجد قسم واحد على الأقل في موقعك.
		يمكنك إنشائه من خلال قائمة «تحرير» قم «الأقسام».',
	'c_job' => 'Les travaux à faire…', # الأعمال قيد الإتمام...
	'c_job_texte' => 'تعرض هذه الصفحة مهمات الصيانة القادمة
		التي سينفذها SPIP. يتم تنفيذ تلك المهمات في فترات منتظمة 
او بشكل ظرفي لمعالجات ثقيلة تتطلبها بعض الملحقات
		كإرسال البريد الكثيف.',
	'c_rubrique_publier' => 'إنشاء مقال',
	'c_rubrique_publier_texte' => 'لا يمكن ان يظهر اي قسم في الموقع العمومي
		الا حين يكون فيه محتوى منشور. مثلاً مقال منشور.
  		قم اذاً بإنشاء مقال. يمكنك إنشاءه من هذه الصفحة، تحت وصف القسم.',
	'c_rubriques_creer' => 'إنشاء أول قسم!',
	'c_rubriques_creer_texte' => 'الأقسام هي البنية الأساسية للموقع. يمكنك إنشاء مقالات في داخل كل منها.
		فابدأ بإنشاء القسم الأول.',
	'c_sites_creer' => 'كيف يتم إنشاء او اسيراد موقع؟',
	'c_sites_creer_texte' => 'لا يمكنك إنشاء او اسيتراد موقع من هذه الصفحة الا لدى وجود قسم واحد على الاقل في الموقعك.
يمكن إنشاء قسم جديد من قائمة «تحرير»، ثم «الأقسام».',

	// E
	'explication_activer_compagnon' => 'يضيف الرفيق تعليقات على بعض صفحات
		المجال الخاص للمساعدة في التأقلم مع SPIP. هل ترغب في تفعيله؟',
	'explication_reinitialiser_compagnon' => 'لا تعود الرسائل التي شاهدتها مؤلف تظهر في ما يعد.
		هل ترغب في إعادة تأصيل هذه الرسائل؟ ',

	// L
	'label_activer_compagnon' => 'تفعيل الرفيق؟',
	'label_reinitialiser_compagnon' => 'إعادة تأصيل رسائل الرفيق؟',

	// O
	'ok' => 'موافق',
	'ok_bien' => 'حسناً!',
	'ok_jai_compris' => 'فهمت!',
	'ok_merci' => 'شكراً',
	'ok_parfait' => 'تمام!',

	// R
	'reinitialisation' => 'إعادة تأصيل',
	'reinitialisation_ok' => 'تمت إعادة التأصيل.',
	'reinitialiser' => 'إعادة تأصيل',
	'reinitialiser_moi' => 'نعم، ولكن التي قرأتها فقط',
	'reinitialiser_tous' => 'نعم، أي كان المؤلف',

	// T
	'titre_compagnon' => 'الرفيق',
	'titre_page_configurer_compagnon' => 'إعداد الرفيق'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_tout_compris' => 'حجب كل رسائل الرفيق',
	'bouton_tout_compris_explication' => 'اذا كنتم تتقنون SPIP، يمكنكم تجاهل كل رسائل الرفيق. عدا عن ذلك يمكن إغلاق كل رسالة على حدة.',

	// C
	'c_accueil_bienvenue' => 'أهلاً وسهلاً @nom@!',
	'c_accueil_configurer_site' => 'إعداد موقعك',
	'c_accueil_configurer_site_texte' => 'أول ما يجب القيام به هو إعطاء اسم لموقعك.
		اسمه الآن «@nom@». سيتم عرض اسم الموقع في أعلى هذه الصفحة.
		بالنقر عليه، يمكن تغيير اسمه واعطاءه رمز وشعار.
',
	'c_accueil_publication' => 'أنشر!',
	'c_accueil_publication_texte' => 'لنشر صفحة، يجب إنشاء مقال.
		لذلك من الضروري انشاء قسم واحد على الأقل. ويتم ذلك من قائمة «تحرير» بانقر على «الأقسام».',
	'c_accueil_texte' => 'دخلت الآن في المجال الخاص في SPIP.',
	'c_accueil_texte_revenir' => 'تعرض هذه الصفحة أحدث نشاطات التحرير في موقعك.
يمكنك العودة الى هذه الصفحة في اي وقت بالنقر على رمز المنزل،
في القسم الأعلى من الشاشة، تحت اسمك.',
	'c_article_redaction' => 'المقال قيد التحرير',
	'c_article_redaction_redacteur' => 'المقال قيد التحرير',
	'c_article_redaction_redacteur_texte' => 'لعرض مقالك على مدراء الموقع وعلى المحررين الآخرين،
		قم بتغيير وضعيته من «قيد التحرير» الى «معروض للتقييم» في الإطار الجانبي.',
	'c_article_redaction_texte' => 'لنشر هذا المقال في الموقع العمومي، يجب تغيير وضعيته.
		قم بتغيير الوضعية من «قيد التحرير» الى «منشور»، في الإطار الجانبي.',
	'c_articles_creer' => 'كيف يتم إنشاء مقال؟',
	'c_articles_creer_texte' => 'لا يمكنك إنشاء مقال من هذه الصفحة
		الا اذا كان يوجد قسم واحد على الأقل في موقعك.
		يمكنك إنشائه من خلال قائمة «تحرير» قم «الأقسام».',
	'c_job' => 'Les travaux à faire…', # الأعمال قيد الإتمام...
	'c_job_texte' => 'تعرض هذه الصفحة مهمات الصيانة القادمة
		التي سينفذها SPIP. يتم تنفيذ تلك المهمات في فترات منتظمة 
او بشكل ظرفي لمعالجات ثقيلة تتطلبها بعض الملحقات
		كإرسال البريد الكثيف.',
	'c_rubrique_publier' => 'إنشاء مقال',
	'c_rubrique_publier_texte' => 'لا يمكن ان يظهر اي قسم في الموقع العمومي
		الا حين يكون فيه محتوى منشور. مثلاً مقال منشور.
  		قم اذاً بإنشاء مقال. يمكنك إنشاءه من هذه الصفحة، تحت وصف القسم.',
	'c_rubriques_creer' => 'إنشاء أول قسم!',
	'c_rubriques_creer_texte' => 'الأقسام هي البنية الأساسية للموقع. يمكنك إنشاء مقالات في داخل كل منها.
		فابدأ بإنشاء القسم الأول.',
	'c_sites_creer' => 'كيف يتم إنشاء او اسيراد موقع؟',
	'c_sites_creer_texte' => 'لا يمكنك إنشاء او اسيتراد موقع من هذه الصفحة الا لدى وجود قسم واحد على الاقل في الموقعك.
يمكن إنشاء قسم جديد من قائمة «تحرير»، ثم «الأقسام».',

	// E
	'explication_activer_compagnon' => 'يضيف الرفيق تعليقات على بعض صفحات
		المجال الخاص للمساعدة في التأقلم مع SPIP. هل ترغب في تفعيله؟',
	'explication_reinitialiser_compagnon' => 'لا تعود الرسائل التي شاهدتها مؤلف تظهر في ما يعد.
		هل ترغب في إعادة تأصيل هذه الرسائل؟ ',

	// L
	'label_activer_compagnon' => 'تفعيل الرفيق؟',
	'label_reinitialiser_compagnon' => 'إعادة تأصيل رسائل الرفيق؟',

	// O
	'ok' => 'موافق',
	'ok_bien' => 'حسناً!',
	'ok_jai_compris' => 'فهمت!',
	'ok_merci' => 'شكراً',
	'ok_parfait' => 'تمام!',

	// R
	'reinitialisation' => 'إعادة تأصيل',
	'reinitialisation_ok' => 'تمت إعادة التأصيل.',
	'reinitialiser' => 'إعادة تأصيل',
	'reinitialiser_moi' => 'نعم، ولكن التي قرأتها فقط',
	'reinitialiser_tous' => 'نعم، أي كان المؤلف',

	// T
	'titre_compagnon' => 'الرفيق',
	'titre_page_configurer_compagnon' => 'إعداد الرفيق'
);
